@@ -57,7 +57,7 @@ local SetLeaderboardForPlayer = function(player_num, leaderboard, leaderboardDat
 					gsEntry["rank"]..".",
 					gsEntry["name"],
 					string.format("%.2f%%", gsEntry["score"]/100),
-					ParseGroovestatsDate(gsEntry["date"]),
+					ParseGrooveStatsDate(gsEntry["date"]),
 					entry
 				)
 				if gsEntry["isRival"] then
@@ -186,7 +186,7 @@ local LeaderboardRequestProcessor = function(res, master)
 
 		if data[playerStr] then
 			master[pn].isRanked = data[playerStr]["isRanked"]
-			if SL["P"..i].ActiveModifiers.ShowEXScore then
+			if SL["P"..i].ActiveModifiers.ShowExScore then
 				-- If the player is using EX scoring, then we want to display the EX leaderboard first.
 				if data[playerStr]["exLeaderboard"] then
 					leaderboardList[#leaderboardList + 1] = {
@@ -342,7 +342,7 @@ local af = Def.ActorFrame{
 						local leaderboard = self:GetParent():GetChild(pn.."Leaderboard")
 						local leaderboardList = self:GetParent()[pn]["Leaderboards"]
 						leaderboardList[#leaderboardList + 1] = {
-							Name="Groovestats",
+							Name="GrooveStats",
 							Disabled=true,
 							IsEX=false
 						}
@@ -559,7 +559,7 @@ for player in ivalues( PlayerNumber ) do
 
 			LoadFont("Common Normal").. {
 				Name="Text",
-				Text=THEME:GetString("Groovestats", "MoreLeaderboards"),
+				Text=THEME:GetString("GrooveStats", "MoreLeaderboards"),
 				InitCommand=function(self)
 					self:diffuse(Color.White)
 				end,
@@ -615,7 +615,7 @@ for player in ivalues( PlayerNumber ) do
 
 			LoadFont("Common Normal").. {
 				Name="Name",
-				Text=(i==1 and THEME:GetString("Groovestats", "Loading") or ""),
+				Text=(i==1 and THEME:GetString("GrooveStats", "Loading") or ""),
 				InitCommand=function(self)
 					self:horizalign(center)
 					self:maxwidth(130)
@@ -623,7 +623,7 @@ for player in ivalues( PlayerNumber ) do
 					self:diffuse(Color.White)
 				end,
 				ResetEntryMessageCommand=function(self)
-					self:settext(i==1 and THEME:GetString("Groovestats", "Loading") or "")
+					self:settext(i==1 and THEME:GetString("GrooveStats", "Loading") or "")
 					self:diffuse(Color.White)
 				end
 			},
