@@ -505,17 +505,41 @@ LoadUnlocksCache()
 -- or SM(text)
 
 local bmt = nil
+local totalVisibleLines = 19
 
 -- SystemMessage ActorFrame
 t[#t+1] = Def.ActorFrame {
+	InitCommand=function(self)
+		self.IsDisplaying = false
+	end,
+	OnCommand=function(self)
+		self.IsDisplaying = true
+	end,
+	OffCommand=function(self)
+		self.IsDisplaying = false
+	end,
 	SystemMessageMessageCommand=function(self, params)
-		bmt:settext( params.Message )
+		if self.IsDisplaying then
+			self:finishtweening()
+			local newText = bmt:GetText().."\n"..params.Message
+			-- Display only the last few lines of text
+			local lines = {}
+			for line in newText:gmatch("[^\n]+") do
+				lines[#lines+1] = line
+			end
+			local start = math.max(#lines - totalVisibleLines, 1)
+			local displayText = table.concat(lines, "\n", start, #lines)
+			bmt:settext(displayText)
+		else
+			bmt:settext( params.Message )
+		end
 
-		self:playcommand( "On" )
+		self:playcommand( "On", params )
 		if params.NoAnimate then
 			self:finishtweening()
 		end
-		self:playcommand( "Off", params )
+
+		self:sleep(type(params.Duration)=="number" and params.Duration or 3.33 + 0.25):queuecommand("Off")
 	end,
 	HideSystemMessageMessageCommand=function(self) self:finishtweening() end,
 
